django\_opt\_out.management.commands package
============================================

Submodules
----------

django\_opt\_out.management.commands.opt\_out\_feedback\_defaults module
------------------------------------------------------------------------

.. automodule:: django_opt_out.management.commands.opt_out_feedback_defaults
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: django_opt_out.management.commands
    :members:
    :undoc-members:
    :show-inheritance:
